@@ -18,9 +18,9 @@ test_that("DCTdenoising",
 	expect_equal(DenoiseDCT(notim, sdn_c), NULL)
     expect_warning(DenoiseDCT(notim, sdn_c))
 	expect_equal(DenoiseDCT(gim2, sdn_c), NULL)
-	expect_warning(DenoiseDCT(gim2, s_c))
-    expect_equal(DenoiseDCT(im, s_c), NULL)
-	expect_warning(DenoiseDCT(im, s_c))
+	expect_warning(DenoiseDCT(gim2, sdn_c))
+    expect_equal(DenoiseDCT(im, sdn_c), NULL)
+	expect_warning(DenoiseDCT(im, sdn_c))
 	expect_equal(DenoiseDCT(gim, sdn_bad1), NULL)
     expect_warning(DenoiseDCT(gim, sdn_bad1))
 	expect_equal(DenoiseDCT(gim, sdn_bad2), NULL)
